==> v1.0.0.tar.gz: platomix-gmetry-bi/platomix-gmetry-bi-api/src/main/java/org/springblade/subscribe/task/SubscribeJobHandler.java <==
/**
 * 
 */
package org.springblade.subscribe.task;

import java.io.File;
import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import org.springblade.message.enums.MsgType;
import org.springblade.message.model.AppMsgInfo;
import org.springblade.message.model.AppMsgRequest;
import org.springblade.message.model.EmailInfo;
import org.springblade.message.model.EmailMsgRequest;
import org.springblade.message.model.MsgResponse;
import org.springblade.subscribe.entity.VisualSubscribe;
import org.springblade.subscribe.entity.VisualSubscribeNotifyConf;
import org.springblade.subscribe.entity.VisualSubscribePushLog;
import org.springblade.subscribe.enums.NotifyType;
import org.springblade.subscribe.service.VisualSubscribeNotifyConfService;
import org.springblade.subscribe.service.VisualSubscribePushLogService;
import org.springblade.subscribe.service.VisualSubscribeService;
import org.springblade.subscribe.task.handler.VisualDataPdfHandler;
import org.springblade.system.client.UserClient;
import org.springblade.system.client.model.UserModel;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import com.xxl.job.core.biz.model.ReturnT;
import com.xxl.job.core.context.XxlJobHelper;
import com.xxl.job.core.handler.annotation.XxlJob;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.extra.spring.SpringUtil;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;

/**
 * @author wookvn
 * 
 */
@Slf4j
@Component
public class SubscribeJobHandler {

	@Autowired
	private VisualSubscribeService visualSubscribeService;

	@Autowired
	private VisualSubscribePushLogService visualSubscribePushLogService;

	@Autowired
	private UserClient userClient;

	@Autowired
	private VisualSubscribeNotifyConfService notifyConfService;
	
	@Autowired
	private VisualDataPdfHandler visualDataPdfHandler;


	/**
	 * 参数
	 * 
	 * @return
	 */
	@SneakyThrows
	@XxlJob("visualSubscribeJobHandler")
	public ReturnT<String> jobHandler() {
		String errMsg = null;
		String param = XxlJobHelper.getJobParam();
		int subId = Integer.parseInt(param);
		VisualSubscribe visualSubscribe = visualSubscribeService.getById(subId);
		if (visualSubscribe == null) {
			return ReturnT.FAIL;
		}
		String htmlContent = null;
		do {
			// 查询用户信息
			UserModel userModel = userClient.getById(visualSubscribe.getUserId());
			if (visualSubscribe.getNotifyType() == NotifyType.email && StrUtil.isEmpty(userModel.getEmail())) {
				errMsg = "该用户没有邮箱地址";
				break;
			}
			if (visualSubscribe.getNotifyType() == NotifyType.qywechat && StrUtil.isEmpty(userModel.getPhone())) {
				errMsg = "该用户没有手机号码";
				break;
			}
			try {
				//获取大屏快照图片列表
				List<String> imageUrlList = visualDataPdfHandler.getVisualScreenShotImageUrl(visualSubscribe.getUserId(), userModel.getAccount(), Arrays.asList(visualSubscribe.getDataId()), visualSubscribe.getDataType());
				if(CollectionUtil.isEmpty(imageUrlList)) {
					errMsg = "大屏快照图片生成失败";
					break;
				}
				//构造发送的Html内容
				htmlContent = imageUrlList.stream().map(t -> String.format("<img src=\"%s\">", t)).collect(Collectors.joining("</br>"));
				MsgResponse msgResponse = null;
				if (visualSubscribe.getNotifyType() == NotifyType.email) {
					String subject = visualSubscribe.getNotifyTitle() + " " + DateUtil.format(new Date(), "yyyyMMdd");
//						sendEmailService.senEmail(userModel.getEmail(),subject,htmlContent);
					/**
					 * 新版本发送邮件方式
					 */
					List<VisualSubscribeNotifyConf> emailConfList = notifyConfService.notifyConfList(NotifyType.email);
					if(CollectionUtil.isNotEmpty(emailConfList)) {
						Map<String, String> emailMap = emailConfList.stream().collect(Collectors.toMap(
								VisualSubscribeNotifyConf::getAttriKey, VisualSubscribeNotifyConf::getAttriValue));
						String username = emailMap.get("username");
						String password = emailMap.get("password");
						String smtp = emailMap.get("smtp");
						EmailInfo emailInfo = EmailInfo.builder().smtpHost(smtp).userName(username).passWord(password).build();
						EmailMsgRequest emailMsgRequest = EmailMsgRequest.builder().body(htmlContent).title(subject).msgType(MsgType.email).emails(Arrays.asList(userModel.getEmail())).emailInfo(emailInfo).build();
						//发送邮件
						msgResponse = SpringUtil.getBean(MsgType.email.getClazz()).sendEmailMessage(emailMsgRequest);
					}
				} else {
					// 将图片转换成pdf文件
					File file = visualDataPdfHandler.buildImagePdf(imageUrlList, visualSubscribe.getSubTitle());
					List<VisualSubscribeNotifyConf> list = notifyConfService.notifyConfList(visualSubscribe.getNotifyType());
					Map<String, String> map = list.stream().collect(Collectors.toMap(VisualSubscribeNotifyConf::getAttriKey, VisualSubscribeNotifyConf::getAttriValue));
					if (visualSubscribe.getNotifyType() == NotifyType.qywechat) {
						// 发送企业微信
//							errMsg = sendMessage(userModel.getPhone(), file, visualSubscribe.getSubTitle(), map);
						AppMsgInfo appMsgInfo = AppMsgInfo.builder().agentId(map.get("agent_id")).corpSecret(map.get("corp_secret")).appId(map.get("corp_id"))
								.appSecret(map.get("app_secret")).build();
						AppMsgRequest appMsgRequest = AppMsgRequest.builder().file(file).phones(Arrays.asList(userModel.getPhone())).appMsgInfo(appMsgInfo)
								.title(visualSubscribe.getSubTitle()).msgType(MsgType.appQywechat).build();
						msgResponse = SpringUtil.getBean(MsgType.appQywechat.getClazz()).sendAppMessage(appMsgRequest);
					} else if (visualSubscribe.getNotifyType() == NotifyType.dingtalk) {
						// 发送钉钉消息
//							errMsg = sendDingTalkMessage(userModel.getPhone(), file, visualSubscribe.getSubTitle(), map);
						AppMsgInfo appMsgInfo = AppMsgInfo.builder().agentId(map.get("agent_id")).appId(map.get("app_key"))
								.appSecret(map.get("app_secret")).build();
						AppMsgRequest appMsgRequest = AppMsgRequest.builder().file(file).phones(Arrays.asList(userModel.getPhone())).appMsgInfo(appMsgInfo)
								.title(visualSubscribe.getSubTitle()).msgType(MsgType.appDingtalk).build();
						msgResponse = SpringUtil.getBean(MsgType.appDingtalk.getClazz()).sendAppMessage(appMsgRequest);
					} else if (visualSubscribe.getNotifyType() == NotifyType.feishu) {
						// 发送飞书消息
//							errMsg = sendFeiShuMessage(userModel.getPhone(), file, visualSubscribe.getSubTitle(), map);
						AppMsgInfo appMsgInfo = AppMsgInfo.builder().appId(map.get("app_id")).appSecret(map.get("app_secret")).build();
						AppMsgRequest appMsgRequest = AppMsgRequest.builder().file(file).phones(Arrays.asList(userModel.getPhone())).appMsgInfo(appMsgInfo)
								.title(visualSubscribe.getSubTitle()).msgType(MsgType.appFeishu).build();
						msgResponse = SpringUtil.getBean(MsgType.appFeishu.getClazz()).sendAppMessage(appMsgRequest);
					}
				}
				if(msgResponse != null && !msgResponse.isSuccess()) {
					errMsg = msgResponse.getMsg();
				}
			} catch (Exception e) {
				log.error(e.getMessage(), e);
				errMsg = "出现异常|errMsg=" + e.getMessage();
			}
		} while (false);
		// 入库日志记录
		VisualSubscribePushLog entity = new VisualSubscribePushLog();
		entity.setCreateTime(new Date());
		entity.setDataId(visualSubscribe.getDataId());
		entity.setDataType(visualSubscribe.getDataType());
		entity.setNotifyType(visualSubscribe.getNotifyType());
		entity.setUserId(visualSubscribe.getUserId());
		entity.setUserName(visualSubscribe.getUserName());
		entity.setSubTitle(visualSubscribe.getSubTitle());
		entity.setContent(htmlContent);
		entity.setErrCode(StrUtil.isEmpty(errMsg) ? 0 : 1);
		entity.setErrMsg(errMsg);
		visualSubscribePushLogService.save(entity);
		return ReturnT.SUCCESS;
	}
}

==> v3.4.1.tar.gz: platomix-gmetry-bi/platomix-gmetry-bi-api/src/main/java/org/springblade/subscribe/task/SubscribeJobHandler.java <==
/**
 * 
 */
package org.springblade.subscribe.task;

import java.io.File;
import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import org.springblade.message.enums.MsgType;
import org.springblade.message.model.AppMsgInfo;
import org.springblade.message.model.AppMsgRequest;
import org.springblade.message.model.EmailInfo;
import org.springblade.message.model.EmailMsgRequest;
import org.springblade.message.model.MsgResponse;
import org.springblade.subscribe.entity.VisualSubscribe;
import org.springblade.subscribe.entity.VisualSubscribeNotifyConf;
import org.springblade.subscribe.entity.VisualSubscribePushLog;
import org.springblade.subscribe.enums.DataType;
import org.springblade.subscribe.enums.NotifyType;
import org.springblade.subscribe.service.VisualSubscribeNotifyConfService;
import org.springblade.subscribe.service.VisualSubscribePushLogService;
import org.springblade.subscribe.service.VisualSubscribeService;
import org.springblade.subscribe.task.handler.VisualDataPdfHandler;
import org.springblade.system.client.UserClient;
import org.springblade.system.client.model.UserModel;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import com.xxl.job.core.biz.model.ReturnT;
import com.xxl.job.core.context.XxlJobHelper;
import com.xxl.job.core.handler.annotation.XxlJob;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.extra.spring.SpringUtil;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;

/**
 * @author wookvn
 * 
 */
@Slf4j
@Component
public class SubscribeJobHandler {

	@Autowired
	private VisualSubscribeService visualSubscribeService;

	@Autowired
	private VisualSubscribePushLogService visualSubscribePushLogService;

	@Autowired
	private UserClient userClient;

	@Autowired
	private VisualSubscribeNotifyConfService notifyConfService;
	
	@Autowired
	private VisualDataPdfHandler visualDataPdfHandler;


	/**
	 * 参数
	 * 
	 * @return
	 */
	@SneakyThrows
	@XxlJob("visualSubscribeJobHandler")
	public ReturnT<String> jobHandler() {
		String errMsg = null;
		String param = XxlJobHelper.getJobParam();
		int subId = Integer.parseInt(param);
		VisualSubscribe visualSubscribe = visualSubscribeService.getById(subId);
		if (visualSubscribe == null) {
			return ReturnT.FAIL;
		}
		String htmlContent = null;
		do {
			// 查询用户信息
			UserModel userModel = userClient.getById(visualSubscribe.getUserId());
			if (visualSubscribe.getNotifyType() == NotifyType.email && StrUtil.isEmpty(userModel.getEmail())) {
				errMsg = "该用户没有邮箱地址";
				break;
			}
			if (visualSubscribe.getNotifyType() != NotifyType.email && StrUtil.isEmpty(userModel.getPhone())) {
				errMsg = "该用户没有手机号码";
				break;
			}
			try {
				//获取大屏快照图片列表
				List<String> imageUrlList = visualDataPdfHandler.getVisualScreenShotImageUrl(visualSubscribe.getUserId(), userModel.getAccount(), Arrays.asList(visualSubscribe.getDataId()), visualSubscribe.getDataType());
				if(CollectionUtil.isEmpty(imageUrlList)) {
					errMsg = "大屏快照图片生成失败";
					break;
				}
				//构造发送的Html内容
				htmlContent = imageUrlList.stream().map(t -> String.format("<img src=\"%s\">", t)).collect(Collectors.joining("</br>"));
				MsgResponse msgResponse = null;
				if (visualSubscribe.getNotifyType() == NotifyType.email) {
					String subject="";
					if (visualSubscribe.getDataType()== DataType.visual){
						subject = "(大屏):"+visualSubscribe.getNotifyTitle() + " " + DateUtil.format(new Date(), "yyyyMMdd");
					}else if (visualSubscribe.getDataType()== DataType.report){
						subject = "(自助报表):"+visualSubscribe.getNotifyTitle() + " " + DateUtil.format(new Date(), "yyyyMMdd");
					}else {
						subject = "(幻灯片):"+visualSubscribe.getNotifyTitle() + " " + DateUtil.format(new Date(), "yyyyMMdd");
					}
//						sendEmailService.senEmail(userModel.getEmail(),subject,htmlContent);
					/**
					 * 新版本发送邮件方式
					 */
					List<VisualSubscribeNotifyConf> emailConfList = notifyConfService.notifyConfList(NotifyType.email);
					if(CollectionUtil.isNotEmpty(emailConfList)) {
						Map<String, String> emailMap = emailConfList.stream().collect(Collectors.toMap(
								VisualSubscribeNotifyConf::getAttriKey, VisualSubscribeNotifyConf::getAttriValue));
						String username = emailMap.get("username");
						String password = emailMap.get("password");
						String smtp = emailMap.get("smtp");
						EmailInfo emailInfo = EmailInfo.builder().smtpHost(smtp).userName(username).passWord(password).build();
						EmailMsgRequest emailMsgRequest = EmailMsgRequest.builder().body(htmlContent).title(subject).msgType(MsgType.email).emails(Arrays.asList(userModel.getEmail())).emailInfo(emailInfo).build();
						//发送邮件
						msgResponse = SpringUtil.getBean(MsgType.email.getClazz()).sendEmailMessage(emailMsgRequest);
					}
				} else {
					// 将图片转换成pdf文件
					File file = visualDataPdfHandler.buildImagePdf(imageUrlList, visualSubscribe.getSubTitle());
					List<VisualSubscribeNotifyConf> list = notifyConfService.notifyConfList(visualSubscribe.getNotifyType());
					Map<String, String> map = list.stream().collect(Collectors.toMap(VisualSubscribeNotifyConf::getAttriKey, VisualSubscribeNotifyConf::getAttriValue));
					if (visualSubscribe.getNotifyType() == NotifyType.qywechat) {
						// 发送企业微信
//							errMsg = sendMessage(userModel.getPhone(), file, visualSubscribe.getSubTitle(), map);
						AppMsgInfo appMsgInfo = AppMsgInfo.builder().agentId(map.get("agent_id")).corpSecret(map.get("corp_secret")).appId(map.get("corp_id"))
								.appSecret(map.get("app_secret")).build();
						AppMsgRequest appMsgRequest = AppMsgRequest.builder().file(file).phones(Arrays.asList(userModel.getPhone())).appMsgInfo(appMsgInfo)
								.title(visualSubscribe.getSubTitle()).msgType(MsgType.appQywechat).build();
						msgResponse = SpringUtil.getBean(MsgType.appQywechat.getClazz()).sendAppMessage(appMsgRequest);
					} else if (visualSubscribe.getNotifyType() == NotifyType.dingtalk) {
						// 发送钉钉消息
//							errMsg = sendDingTalkMessage(userModel.getPhone(), file, visualSubscribe.getSubTitle(), map);
						AppMsgInfo appMsgInfo = AppMsgInfo.builder().agentId(map.get("agent_id")).appId(map.get("app_key"))
								.appSecret(map.get("app_secret")).build();
						AppMsgRequest appMsgRequest = AppMsgRequest.builder().file(file).phones(Arrays.asList(userModel.getPhone())).appMsgInfo(appMsgInfo)
								.title(visualSubscribe.getSubTitle()).msgType(MsgType.appDingtalk).build();
						msgResponse = SpringUtil.getBean(MsgType.appDingtalk.getClazz()).sendAppMessage(appMsgRequest);
					} else if (visualSubscribe.getNotifyType() == NotifyType.feishu) {
						// 发送飞书消息
//							errMsg = sendFeiShuMessage(userModel.getPhone(), file, visualSubscribe.getSubTitle(), map);
						AppMsgInfo appMsgInfo = AppMsgInfo.builder().appId(map.get("app_id")).appSecret(map.get("app_secret")).build();
						AppMsgRequest appMsgRequest = AppMsgRequest.builder().file(file).phones(Arrays.asList(userModel.getPhone())).appMsgInfo(appMsgInfo)
								.title(visualSubscribe.getSubTitle()).msgType(MsgType.appFeishu).build();
						msgResponse = SpringUtil.getBean(MsgType.appFeishu.getClazz()).sendAppMessage(appMsgRequest);
					}
				}
				if(msgResponse != null && !msgResponse.isSuccess()) {
					errMsg = msgResponse.getMsg();
				}
			} catch (Exception e) {
				log.error(e.getMessage(), e);
				errMsg = "出现异常|errMsg=" + e.getMessage();
			}
		} while (false);
		// 入库日志记录
		VisualSubscribePushLog entity = new VisualSubscribePushLog();
		entity.setCreateTime(new Date());
		entity.setDataId(visualSubscribe.getDataId());
		entity.setDataType(visualSubscribe.getDataType());
		entity.setNotifyType(visualSubscribe.getNotifyType());
		entity.setUserId(visualSubscribe.getUserId());
		entity.setUserName(visualSubscribe.getUserName());
		entity.setSubTitle(visualSubscribe.getSubTitle());
		entity.setContent(htmlContent);
		entity.setErrCode(StrUtil.isEmpty(errMsg) ? 0 : 1);
		entity.setErrMsg(errMsg);
		visualSubscribePushLogService.save(entity);
		return ReturnT.SUCCESS;
	}
}
